==> emelfm2-0.1.2.tar.gz: emelfm2-0.1.2/src/config/e2_option_sel.h <==
/* $Id: e2_option_sel.h 762 2005-05-13 04:00:38Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef E2_OPTION_SEL_H
#define E2_OPTION_SEL_H

#include "emelfm2.h"
#include "e2_option.h"

GtkWidget *e2_option_sel_add_menu_widget (GtkWidget *controller,
	GtkWidget *menu, E2_OptionSet *set, gpointer func, gpointer data);
void e2_option_sel_add_widget (GtkWidget *dialog, GtkWidget *box,
	GtkSizeGroup *size_group, E2_OptionSet *set);
E2_OptionSet *e2_option_sel_register (gchar *name, gchar *group, gchar *desc,
	gchar *tip, gchar *depends, gint def, gchar **values, E2_OptionFlags flags);
gint e2_option_sel_set (gchar *option, gint value);
gint _e2_option_sel_set (E2_OptionSet *set, gint value);
gint e2_option_sel_get (gchar *option);
gint _e2_option_sel_get (E2_OptionSet *set);

#endif // ndef E2_OPTION_SEL_H

==> emelfm2-0.1.7.tar.gz: emelfm2-0.1.7/src/config/e2_option_sel.h <==
/* $Id: e2_option_sel.h 1856 2006-04-24 12:51:28Z tpgww $
 * 
 * Copyright (C) 2004-2005 tooar <tooar@gmx.net>
 * 
 * This file is part of emelFM2.
 * emelFM2 is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * emelFM2 is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with emelFM2; see the file GPL. If not, contact the Free Software
 * Foundation, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */

#ifndef E2_OPTION_SEL_H
#define E2_OPTION_SEL_H

#include "emelfm2.h"
#include "e2_option.h"

GtkWidget *e2_option_sel_add_menu_widget (GtkWidget *controller,
	GtkWidget *menu, E2_OptionSet *set, gpointer func, gpointer data);
void e2_option_sel_add_widget (GtkWidget *dialog, GtkWidget *box,
	GtkSizeGroup *size_group, E2_OptionSet *set);
E2_OptionSet *e2_option_sel_register (gchar *name, gchar *group, gchar *desc,
	gchar *tip, gchar *depends, gint def, const gchar **values,
	E2_OptionFlags flags);
gint e2_option_sel_set (gchar *option, gint value);
gint e2_option_sel_set_direct (E2_OptionSet *set, gint value);
gint e2_option_sel_get (gchar *option);
gint e2_option_sel_get_direct (E2_OptionSet *set);

#endif // ndef E2_OPTION_SEL_H
